spannertools.Tie
================

.. abjad-lineage:: abjad.tools.spannertools.Tie.Tie

.. autoclass:: abjad.tools.spannertools.Tie.Tie

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.Tie.Tie.append
      ~abjad.tools.spannertools.Tie.Tie.append_left
      ~abjad.tools.spannertools.Tie.Tie.components
      ~abjad.tools.spannertools.Tie.Tie.detach
      ~abjad.tools.spannertools.Tie.Tie.direction
      ~abjad.tools.spannertools.Tie.Tie.extend
      ~abjad.tools.spannertools.Tie.Tie.extend_left
      ~abjad.tools.spannertools.Tie.Tie.fracture
      ~abjad.tools.spannertools.Tie.Tie.fuse
      ~abjad.tools.spannertools.Tie.Tie.get_duration
      ~abjad.tools.spannertools.Tie.Tie.get_timespan
      ~abjad.tools.spannertools.Tie.Tie.index
      ~abjad.tools.spannertools.Tie.Tie.leaves
      ~abjad.tools.spannertools.Tie.Tie.pop
      ~abjad.tools.spannertools.Tie.Tie.pop_left
      ~abjad.tools.spannertools.Tie.Tie.__contains__
      ~abjad.tools.spannertools.Tie.Tie.__copy__
      ~abjad.tools.spannertools.Tie.Tie.__eq__
      ~abjad.tools.spannertools.Tie.Tie.__format__
      ~abjad.tools.spannertools.Tie.Tie.__getitem__
      ~abjad.tools.spannertools.Tie.Tie.__len__
      ~abjad.tools.spannertools.Tie.Tie.__lt__
      ~abjad.tools.spannertools.Tie.Tie.__ne__
      ~abjad.tools.spannertools.Tie.Tie.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Tie.Tie.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Tie.Tie.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.Tie.Tie.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.Tie.Tie.append
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.index
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.Tie.Tie.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Tie.Tie.__repr__
   :noindex:
